==> haskell-sdl2-ttf-2.1.3-244-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-sdl2-ttf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   sdl2-ttf
version:                2.1.3
visibility:             public
id:                     sdl2-ttf-2.1.3-79HyxwujDoFBtSW9qErYZP
key:                    sdl2-ttf-2.1.3-79HyxwujDoFBtSW9qErYZP
license:                BSD-3-Clause
copyright:
    Copyright © 2013-2022 Ömer Sinan Ağacan, Siniša Biđin, Rongcui Dong and others (see git commits)

maintainer:             Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:
    Rongcui Dong (rongcuid@outlook.com),
    Siniša Biđin <sinisa@bidin.eu>,
    Ömer Sinan Ağacan (omeragacan@gmail.com),
    Sean Chalmers (sclhiannan@gmail.com)

synopsis:               Bindings to SDL2_ttf.
description:
    Haskell bindings to SDL2_ttf C++ library <https://github.com/libsdl-org/SDL_ttf>.

category:               Font, Foreign binding, Graphics
abi:                    f051c8b7bf0eadaea5270394f4fd02c2
exposed:                True
exposed-modules:        SDL.Font SDL.Raw.Font
hidden-modules:         SDL.Raw.Helper
import-dirs:            /usr/lib/ghc-9.4.8/site-local/sdl2-ttf-2.1.3
library-dirs:           /usr/lib/ghc-9.4.8/site-local/sdl2-ttf-2.1.3
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/sdl2-ttf-2.1.3
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-sdl2-ttf
hs-libraries:           HSsdl2-ttf-2.1.3-79HyxwujDoFBtSW9qErYZP
extra-libraries:        SDL2_ttf SDL2
extra-libraries-static:
    SDL2_ttf SDL2 harfbuzz m glib-2.0 m sysprof-capture-4 pcre2-8
    graphite2 freetype dl bz2 png16 m m z brotlidec brotlicommon

include-dirs:
    /usr/include/SDL2 /usr/include/harfbuzz /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/sysprof-6
    /usr/include/freetype2 /usr/include/libpng16

depends:
    base-4.17.2.1 bytestring-0.11.5.3
    sdl2-2.5.5.1-2V0AydMQKEy7hsfNPqMTef template-haskell-2.19.0.0
    text-2.0.2 th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    transformers-0.5.6.2

haddock-interfaces:     /usr/share/doc/haskell-sdl2-ttf/html/sdl2-ttf.haddock
haddock-html:           /usr/share/doc/haskell-sdl2-ttf/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sdl2-ttf-2.1.3-265-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-sdl2-ttf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   sdl2-ttf
version:                2.1.3
visibility:             public
id:                     sdl2-ttf-2.1.3-Ki4HAmmCPsdAkOxnTA0d7A
key:                    sdl2-ttf-2.1.3-Ki4HAmmCPsdAkOxnTA0d7A
license:                BSD-3-Clause
copyright:
    Copyright © 2013-2022 Ömer Sinan Ağacan, Siniša Biđin, Rongcui Dong and others (see git commits)

maintainer:             Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:
    Rongcui Dong (rongcuid@outlook.com),
    Siniša Biđin <sinisa@bidin.eu>,
    Ömer Sinan Ağacan (omeragacan@gmail.com),
    Sean Chalmers (sclhiannan@gmail.com)

synopsis:               Bindings to SDL2_ttf.
description:
    Haskell bindings to SDL2_ttf C++ library <https://github.com/libsdl-org/SDL_ttf>.

category:               Font, Foreign binding, Graphics
abi:                    04e2628124a273d87529f7a3f8fce6f9
exposed:                True
exposed-modules:        SDL.Font SDL.Raw.Font
hidden-modules:         SDL.Raw.Helper
import-dirs:            /usr/lib/ghc-9.4.8/site-local/sdl2-ttf-2.1.3
library-dirs:           /usr/lib/ghc-9.4.8/site-local/sdl2-ttf-2.1.3
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/sdl2-ttf-2.1.3
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-sdl2-ttf
hs-libraries:           HSsdl2-ttf-2.1.3-Ki4HAmmCPsdAkOxnTA0d7A
extra-libraries:        SDL2_ttf SDL2
extra-libraries-static:
    SDL2_ttf SDL2 harfbuzz m glib-2.0 m sysprof-capture-4 pcre2-8
    graphite2 freetype dl bz2 png16 m m z brotlidec brotlicommon

include-dirs:
    /usr/include/SDL2 /usr/include/harfbuzz /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/sysprof-6
    /usr/include/freetype2 /usr/include/libpng16

depends:
    base-4.17.2.1 bytestring-0.11.5.3
    sdl2-2.5.5.1-Lao0p9HnGdU6BBHU9oyBsw template-haskell-2.19.0.0
    text-2.0.2 th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    transformers-0.5.6.2

haddock-interfaces:     /usr/share/doc/haskell-sdl2-ttf/html/sdl2-ttf.haddock
haddock-html:           /usr/share/doc/haskell-sdl2-ttf/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
